@@ -250,15 +250,13 @@ on_network_monitor_network_changed (GoaDaemon *self, gboolean available)
 static void
 goa_daemon_init (GoaDaemon *self)
 {
-  static volatile GQuark goa_error_domain = 0;
   GoaObjectSkeleton *object;
   gchar *path;
 
   /* this will force associating errors in the GOA_ERROR error domain
    * with org.freedesktop.Goa.Error.* errors via g_dbus_error_register_error_domain().
    */
-  goa_error_domain = GOA_ERROR;
-  goa_error_domain; /* shut up -Wunused-but-set-variable */
+  goa_error_quark ();
 
   goa_provider_ensure_builtins_loaded ();
 
@@ -535,14 +533,14 @@ add_config_file (GoaDaemon     *self,
                   if (provider_type != NULL)
                     provider = goa_provider_get_for_provider_type (provider_type);
 
+                  needs_update = g_key_file_remove_group (key_file, groups[n], NULL) || needs_update;
+
                   if (provider == NULL)
                     {
-                      g_warning ("Unsupported account type %s for ID %s (no provider)", provider_type, id);
+                      g_debug ("Unsupported account type %s for ID %s (no provider)", provider_type, id);
                       goto cleanup_and_continue;
                     }
 
-                  needs_update = g_key_file_remove_group (key_file, groups[n], NULL);
-
                   error = NULL;
                   if (!goa_utils_delete_credentials_for_id_sync (provider, id, NULL, &error))
                     {
@@ -562,7 +560,7 @@ add_config_file (GoaDaemon     *self,
             }
           else
             {
-              needs_update = g_key_file_remove_key (key_file, groups[n], "SessionId", NULL);
+              needs_update = g_key_file_remove_key (key_file, groups[n], "SessionId", NULL) || needs_update;
             }
 
           g_hash_table_insert (group_name_to_key_file_data,
@@ -647,7 +645,7 @@ update_account_object (GoaDaemon           *self,
   provider = goa_provider_get_for_provider_type (type);
   if (provider == NULL)
     {
-      g_warning ("Unsupported account type %s for identity %s (no provider)", type, identity);
+      g_debug ("Unsupported account type %s for identity %s (no provider)", type, identity);
       goto out;
     }
 
@@ -1496,7 +1494,7 @@ is_authorization_error (GError *error)
   g_return_val_if_fail (error != NULL, FALSE);
 
   ret = FALSE;
-  if (error->domain == REST_PROXY_ERROR || error->domain == SOUP_HTTP_ERROR)
+  if (error->domain == REST_PROXY_ERROR)
     {
       if (SOUP_STATUS_IS_CLIENT_ERROR (error->code))
         ret = TRUE;
